@@ -2,7 +2,7 @@ package # Hide from CPAN
     LM::Test::Component;
 use Moose;
 
-extends 'Graphics::Primitive::Container';
+extends 'Graphics::Primitive::Component';
 
 sub prepare { }
 
